"""
Main entry point for running the ClickUp MCP Server as a module.

This allows running the server using:
python -m clickup_mcp
"""

from clickup_mcp.entry import main

if __name__ == "__main__":
    main()
